==> org.jresearch.commons.gwt.flexess-1.0.2.jar: org/jresearch/commons/gwt/flexess/client/model/meta/AttributeTemplateModel.java <==
package org.jresearch.commons.gwt.flexess.client.model.meta;

import org.jresearch.commons.gwt.client.model.DomainNewModel;

public class AttributeTemplateModel extends DomainNewModel<String> {

	private static final long serialVersionUID = -5705542024857825838L;

	private String typeDescription;
	private int type;
	private boolean userAttribute;
	private String defaultValue;

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		final StringBuilder builder = new StringBuilder();
		builder.append("AttributeTemplateModel ["); //$NON-NLS-1$
		if (getTypeDescription() != null) {
			builder.append("getTypeDescription()=").append(getTypeDescription()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		builder.append("getType()=").append(getType()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		builder.append("isUserAttribute()=").append(isUserAttribute()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		if (getDefaultValue() != null) {
			builder.append("getDefaultValue()=").append(getDefaultValue()); //$NON-NLS-1$
		}
		builder.append("]"); //$NON-NLS-1$
		return builder.toString();
	}

	/**
	 * @return the typeDescription
	 */
	public String getTypeDescription() {
		return typeDescription;
	}

	/**
	 * @param typeDescription
	 *            the typeDescription to set
	 */
	public void setTypeDescription(final String typeDescription) {
		this.typeDescription = typeDescription;
	}

	/**
	 * @return the type
	 */
	public int getType() {
		return type;
	}

	/**
	 * @param type
	 *            the type to set
	 */
	public void setType(final int type) {
		this.type = type;
	}

	/**
	 * @return the userAttribute
	 */
	public boolean isUserAttribute() {
		return userAttribute;
	}

	/**
	 * @param userAttribute
	 *            the userAttribute to set
	 */
	public void setUserAttribute(final boolean userAttribute) {
		this.userAttribute = userAttribute;
	}

	/**
	 * @return the defaultValue
	 */
	public String getDefaultValue() {
		return defaultValue;
	}

	/**
	 * @param defaultValue
	 *            the defaultValue to set
	 */
	public void setDefaultValue(final String defaultValue) {
		this.defaultValue = defaultValue;
	}

}

==> org.jresearch.commons.gwt.flexess-1.0.8.jar: org/jresearch/commons/gwt/flexess/client/model/meta/AttributeTemplateModel.java <==
package org.jresearch.commons.gwt.flexess.client.model.meta;

import org.jresearch.commons.gwt.shared.model.DomainNewModel;

public class AttributeTemplateModel extends DomainNewModel<String> {

	private static final long serialVersionUID = -5705542024857825838L;

	private String typeDescription;
	private int type;
	private boolean userAttribute;
	private String defaultValue;

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		final StringBuilder builder = new StringBuilder();
		builder.append("AttributeTemplateModel ["); //$NON-NLS-1$
		if (getTypeDescription() != null) {
			builder.append("getTypeDescription()=").append(getTypeDescription()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		builder.append("getType()=").append(getType()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		builder.append("isUserAttribute()=").append(isUserAttribute()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		if (getDefaultValue() != null) {
			builder.append("getDefaultValue()=").append(getDefaultValue()); //$NON-NLS-1$
		}
		builder.append("]"); //$NON-NLS-1$
		return builder.toString();
	}

	/**
	 * @return the typeDescription
	 */
	public String getTypeDescription() {
		return typeDescription;
	}

	/**
	 * @param typeDescription
	 *            the typeDescription to set
	 */
	public void setTypeDescription(final String typeDescription) {
		this.typeDescription = typeDescription;
	}

	/**
	 * @return the type
	 */
	public int getType() {
		return type;
	}

	/**
	 * @param type
	 *            the type to set
	 */
	public void setType(final int type) {
		this.type = type;
	}

	/**
	 * @return the userAttribute
	 */
	public boolean isUserAttribute() {
		return userAttribute;
	}

	/**
	 * @param userAttribute
	 *            the userAttribute to set
	 */
	public void setUserAttribute(final boolean userAttribute) {
		this.userAttribute = userAttribute;
	}

	/**
	 * @return the defaultValue
	 */
	public String getDefaultValue() {
		return defaultValue;
	}

	/**
	 * @param defaultValue
	 *            the defaultValue to set
	 */
	public void setDefaultValue(final String defaultValue) {
		this.defaultValue = defaultValue;
	}

}
